@@ -134,7 +134,9 @@ impl<T: TrustStore> ValClient<T> {
         if total_votes < 0.7 {
             return Err(MelnetError::Custom(format!(
                 "remote height {} has insufficient votes (total_votes = {}, stakers = {:?})",
-                summary.height, total_votes, stakers
+                summary.height,
+                total_votes,
+                stakers.val_iter().collect::<Vec<_>>()
             )));
         }
         // automatically update trust
